@@ -9,13 +9,17 @@ loadTask <- function(project, package, taskname,
                      author=getTaskAuthor(),
                      quiet=FALSE) {
   tabk <- createTask(project,package,taskname,sponsor,author)
-  ta <- readBinary(task=tabk,type="task",quiet=quiet)
-  ## back-compatibility
-  if(!is.null(ta)) {
-    ta$paths <- NULL
-    #ta$paths <- lapply(ta$paths,gsub,pattern=paste0("^",ta$paths$root),replacement="%ROOT%")
-    #ta$paths$root <- "%ROOT%"
+  ta <- readBinary(task=tabk,type="task",quiet=TRUE)
+  if(is.null(ta)) {
+    fn <- file.path(binaryDir(tabk),paste0(tabk$task,"_task.json"))
+    if(file.exists(fn)) {
+      v <- jsonlite::read_json(fn)
+      ta <- tabk
+      for(n in names(v)) ta[[n]] <- unlist(v[[n]])
+    }
   }
+  if(!quiet&&is.null(ta)) message("Task does not exist.")
+  if(!is.null(ta)) ta$paths <- NULL # Back-compatibility 
   ta
 }
 
