@@ -18,8 +18,10 @@ D4getenv <- function(name,desc,quiet=FALSE) {
 #' @return Path to the current task root.
 #' @export
 setTaskRoot <- function(rootpath,dirCreate=FALSE){
+  #rootpath <- normalizePath(rootpath,winslash="/",mustWork=FALSE)
   if(!dirCreate&&!file.exists(rootpath)) stop("root directory does not exist")
   if( dirCreate&&!file.exists(rootpath)) dir.create(rootpath,recursive=TRUE,showWarnings=FALSE)
+  rootpath <- normalizePath(rootpath,winslash="/")
   assign(x="rootpath",value=rootpath,pos=.pkgEnv)
   invisible(getTaskRoot())
 }
